@@ -5,6 +5,7 @@ $.i18n().load({
         "nimgame_single_player": "Играј против рачунара",
         "nimgame_error": "Можеш означити највише $1 кружић",
         "nimgame_winner" : "Играч $1 је победио.",
-        "nimgame_alg_won" : "Рачунар је победио."
+        "nimgame_alg_won" : "Рачунар је победио.",
+        "nimgame_take_away_msg" : "означи од <span>1</span> до <span>$1</span> кружића"
     }
 })
\ No newline at end of file
